@@ -3,3 +3,5 @@ from .concat import concat
 from .iplot import iplot_location, iplot_timeseries
 from .md5 import md5
 from .es_create_indexes import es_create_indexes
+from .emso import EMSO
+from .md_widgets import widget_qc, widget_emso
